<?php
namespace Factory;

use Teknisa\Model\Geral\Entities\OperadorAcesso as OperadorAcessoEntity;
use Util\InstanceProvider;
use Teknisa\Libs\Util\NewCode;

class OperadorAcesso {

    /**
     * @param OperadorAcessoEntity $operadorAcesso
     * @param $productId
     * @param $fingerprint
     * @param $userId
     * @param $orgId
     * @param $dateNow
     * @param $token
     * @param $tokenLifeTime
     * @param $keepConnected
     * @param $connection
     * @return OperadorAcessoEntity
     */

    public function save(OperadorAcessoEntity $operadorAcesso = null, $productId, $fingerprint, $userId, $orgId,
                         $dateNow, $token, $tokenLifeTime, $keepConnected, $connection)
    {
        if(!$operadorAcesso) {
            $newCode = new NewCode($connection, 'NOVO_CODIGO_SC');
            $id = $newCode->getCodeByTableName("OPERADOR_ACESSO", $orgId, 1, 10, true);
            $this->insert($id, $productId, $fingerprint, $userId, $orgId, 
                          $token, $tokenLifeTime, $keepConnected, $connection);
        } else {
            $id = $operadorAcesso->getId();
            $this->update($id, $fingerprint, $userId, $orgId,
                          $token, $tokenLifeTime, $keepConnected, $connection);
        }
    }

    private function insert($id, $productId, $fingerprint, $userId, $orgId, 
                            $token, $tokenLifeTime, $keepConnected, $connection) {
        $query = "INSERT INTO OPERADOR_ACESSO (ID, NRPRODUTO_ID, CDOPERADOR, DSCHAVEULTACESSO, NRORG, IDATIVO,
                                               TOKEN, NRTEMPOVIDATOKEN, IDMANTERCONECTADO,
                                               DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, 
                                               DTULTATU, NRORGULTATU, CDOPERULTATU)
                       VALUES (:ID, :NRPRODUTO_ID, :CDOPERADOR, :DSCHAVEULTACESSO, :NRORG, 'S',
                               :TOKEN, :NRTEMPOVIDATOKEN, :IDMANTERCONECTADO,
                               SYSDATE, :NRORG, :CDOPERADOR,
                               SYSDATE, :NRORG, :CDOPERADOR)";

        $params = array (
            'ID'                => $id,
            'NRPRODUTO_ID'      => $productId,
            'CDOPERADOR'        => $userId,
            'DSCHAVEULTACESSO'  => $fingerprint,
            'NRORG'             => $orgId,
            'TOKEN'             => $token,
            'NRTEMPOVIDATOKEN'  => $tokenLifeTime,
            'IDMANTERCONECTADO' => $keepConnected
        );
        $stmt = $connection->prepare($query);
        $stmt->execute($params);
    }

    private function update($id, $fingerprint, $userId, $orgId,
                            $token, $tokenLifeTime, $keepConnected, $connection) {
        $query = "UPDATE OPERADOR_ACESSO
                     SET DSCHAVEULTACESSO  = :DSCHAVEULTACESSO,                   
                         TOKEN             = :TOKEN,
                         NRTEMPOVIDATOKEN  = :NRTEMPOVIDATOKEN,
                         IDMANTERCONECTADO = :IDMANTERCONECTADO,
                         DTULTATU          = SYSDATE,
                         NRORGULTATU       = :NRORG,
                         CDOPERULTATU      = :CDOPERADOR
                   WHERE ID    = :ID
                     AND NRORG = :NRORG";

        $params = array (
            'ID'                => $id,
            'CDOPERADOR'        => $userId,
            'DSCHAVEULTACESSO'  => $fingerprint,
            'NRORG'             => $orgId,
            'TOKEN'             => $token,
            'NRTEMPOVIDATOKEN'  => $tokenLifeTime,
            'IDMANTERCONECTADO' => $keepConnected
        );
        $stmt = $connection->prepare($query);
        $stmt->execute($params);
    }
}
